@@ -3,7 +3,7 @@ use warnings;
 
 package WebService::Shippo;
 # ABSTRACT: A Shippo Perl API wrapper
-our $VERSION = '0.0.13';
+our $VERSION = '0.0.14';
 require WebService::Shippo::Entities;
 use boolean ':all';
 use Params::Callbacks ( 'callbacks', 'callback' );
@@ -62,24 +62,35 @@ BEGIN {
 
 =head1 NAME
 
-WebService::Shippo - A Shippo API Perl Wrapper (pre-release)
+WebService::Shippo - Shippo API Client
 
 =head1 VERSION
 
-version 0.0.13
+version 0.0.14
+
+=head1 PRE-RELEASE SOFTWARE
+
+B<Though functional, this software is still very much in the process of being
+documented and should therefore be considered a work in progress.> 
+
+=head1 INTRODUCTION
+
+The Shippo API can be used to automate and customize shipping capabilities
+for your e-commerce store or marketplace, enabling you to retrieve shipping 
+rates, create and purchase shipping labels, track packages, and much more.
+
+Shippo connects you with multiple shipping providers (USPS, UPS and Fedex,
+for example) through one interface, offering you great discounts on a
+selection of shipping rates.
+
+You can sign-up for an account at L<https://goshippo.com/>.
 
 =head1 SYNOPIS
 
-Shippo is a shipping API that connects you with multiple shipping providers
-(such as USPS, UPS, and Fedex) through one interface, and offers you great
-discounts on shipping rates.
-
-Don't have an account? Sign up at L<https://goshippo.com/>
-
     use strict;
     use WebService::Shippo;
     
-    # If it hasn't already done outside of the script, you
+    # If it hasn't already been done outside of the script, you
     # must set your API key...
     Shippo->api_key( 'PASTE YOUR PRIVATE AUTH TOKEN HERE' )
         unless Shippo->api_key;
@@ -130,6 +141,10 @@ All being well, you should see something like this:
     
 =head1 DESCRIPTION
 
+Shippo offer official API clients for a bevy of I<major> languages, though
+the venerable Perl is not in that list. This client is a community offering
+that attempts to correct that omission.
+
 =head1 FULL API DOCUMENTATION
 
 =over 2
@@ -145,8 +160,6 @@ questions.
 
 =over 2
 
-=item * L<http://search.cpan.org/dist/WebService-Shippo/lib/WebService/Shippo.pm>
-
 =item * L<https://github.com/cpanic/WebService-Shippo>
 
 =item * L<https://github.com/cpanic/WebService-Shippo/wiki>
@@ -159,7 +172,7 @@ Iain Campbell <cpanic@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Iain Campbell.
+This software is copyright E<copy> 2015 by Iain Campbell.
 
 You may distribute this software under the terms of either the GNU General
 Public License or the Artistic License, as specified in the Perl README
