@@ -47,7 +47,7 @@ BEGIN {
     # Forcing the dev to always use CPAN's perferred "WebService::Shippo"
     # namespace is just cruel; allow the use of "Shippo", too.
     *Shippo::Address::     = *WebService::Shippo::Address::;
-    *Shippo::AddressList:: = *WebService::Shippo::AddressList::;
+    *Shippo::Addresses:: = *WebService::Shippo::Addresses::;
 }
 
 1;
@@ -58,11 +58,11 @@ BEGIN {
 
 =head1 NAME
 
-WebService::Shippo::Address - Work with Shippo Address objects.
+WebService::Shippo::Address - Address class
 
 =head1 VERSION
 
-version 0.0.13
+version 0.0.14
 
 =head1 SYNOPIS
 
@@ -124,7 +124,7 @@ consistently in example code.
     # A bit complicated all that! You could just use an iterator and dispense
     # with all that pagination nonsense; the default results window size is 5
     # but you can increase that to reduce the number of API requests.
-    my $it = Shippo::Address->iterator( results => 25 );
+    my $it = Shippo::Address->iterate( results => 25 );
     while ( my $address = $it->() ) {
         print $address->object_id, "\n";
     }
@@ -299,8 +299,7 @@ and C<object_state> attributes.
 
 =head1 API DOCUMENTATION
 
-For more information about Address objects, consult the Shippo API
-documentation:
+For more information about Addresses, consult the Shippo API documentation:
 
 =over 2
 
