@@ -72,6 +72,7 @@ sub enable_production_mode
 package    # Hide from PAUSE
     WebService::Shippo::CarrierAccounts;
 use base ( 'WebService::Shippo::Collection' );
+
 sub item_class ()       { 'WebService::Shippo::CarrierAccount' }
 sub collection_class () { __PACKAGE__ }
 
@@ -79,8 +80,60 @@ BEGIN {
     no warnings 'once';
     # Forcing the dev to always use CPAN's perferred "WebService::Shippo"
     # namespace is just cruel; allow the use of "Shippo", too.
-    *Shippo::CarrierAccount::     = *WebService::Shippo::CarrierAccount::;
-    *Shippo::CarrierAccountList:: = *WebService::Shippo::CarrierAccountList::;
+    *Shippo::CarrierAccount::  = *WebService::Shippo::CarrierAccount::;
+    *Shippo::CarrierAccounts:: = *WebService::Shippo::CarrierAccounts::;
 }
 
 1;
+
+=pod
+
+=encoding utf8
+
+=head1 NAME
+
+WebService::Shippo::CarrierAccount - Carrier Account class
+
+=head1 VERSION
+
+version 0.0.14
+
+=head1 DESCRIPTION
+
+Carrier accounts are used as credentials to retrieve shipping rates
+and purchase labels from a shipping provider.
+
+=head1 API DOCUMENTATION
+
+For more information about Carrier Accounts, consult the Shippo API
+documentation:
+
+=over 2
+
+=item * L<https://goshippo.com/docs/#carrier-accounts>
+
+=back
+
+=head1 REPOSITORY
+
+=over 2
+
+=item * L<https://github.com/cpanic/WebService-Shippo>
+
+=item * L<https://github.com/cpanic/WebService-Shippo/wiki>
+
+=back
+
+=head1 AUTHOR
+
+Iain Campbell <cpanic@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Iain Campbell.
+
+You may distribute this software under the terms of either the GNU General
+Public License or the Artistic License, as specified in the Perl README
+file.
+
+=cut
