@@ -16,12 +16,13 @@ sub item_class ()       { __PACKAGE__ }
 sub get_shipping_rates
 {
     my ( $invocant, @params ) = @_;
-    WebService::Shippo::Shipment->get_shipping_rates(@params);
+    WebService::Shippo::Shipment->get_shipping_rates( @params );
 }
 
 package    # Hide from PAUSE
     WebService::Shippo::Rates;
 use base ( 'WebService::Shippo::Collection' );
+
 sub item_class ()       { 'WebService::Shippo::Rate' }
 sub collection_class () { __PACKAGE__ }
 
@@ -29,8 +30,8 @@ BEGIN {
     no warnings 'once';
     # Forcing the dev to always use CPAN's perferred "WebService::Shippo"
     # namespace is just cruel; allow the use of "Shippo", too.
-    *Shippo::Rate::     = *WebService::Shippo::Rate::;
-    *Shippo::RateList:: = *WebService::Shippo::RateList::;
+    *Shippo::Rate::  = *WebService::Shippo::Rate::;
+    *Shippo::Rates:: = *WebService::Shippo::Rates::;
 }
 
 1;
@@ -41,11 +42,11 @@ BEGIN {
 
 =head1 NAME
 
-WebService::Shippo::Rate - Work with Shippo Rate objects.
+WebService::Shippo::Rate - Rate class.
 
 =head1 VERSION
 
-version 0.0.13
+version 0.0.14
 
 =head1 DESCRIPTION
 
@@ -80,8 +81,7 @@ on the carrier's server.
 
 =head1 API DOCUMENTATION
 
-For more information about Rate objects, consult the Shippo API
-documentation:
+For more information about Rates, consult the Shippo API documentation:
 
 =over 2
 
