@@ -64,6 +64,7 @@ sub get_shipping_rates
 package    # Hide from PAUSE
     WebService::Shippo::Shipments;
 use base ( 'WebService::Shippo::Collection' );
+
 sub item_class ()       { 'WebService::Shippo::Shipment' }
 sub collection_class () { __PACKAGE__ }
 
@@ -72,9 +73,9 @@ BEGIN {
 
     # Forcing the dev to always use CPAN's perferred "WebService::Shippo"
     # namespace is just cruel; allow the use of "Shippo", too.
-    *Shippo::Shipment::     = *WebService::Shippo::Shipment::;
-    *Shippo::ShipmentList:: = *WebService::Shippo::ShipmentList::;
-    *rates                  = *get_shipping_rates;
+    *Shippo::Shipment::  = *WebService::Shippo::Shipment::;
+    *Shippo::Shipments:: = *WebService::Shippo::Shipments::;
+    *rates               = *get_shipping_rates;
 }
 
 1;
@@ -85,11 +86,11 @@ BEGIN {
 
 =head1 NAME
 
-WebService::Shippo::Shipment - Work with Shippo Shipment objects.
+WebService::Shippo::Shipment - Shipment class.
 
 =head1 VERSION
 
-version 0.0.13
+version 0.0.14
 
 =head1 DESCRIPTION
 
@@ -101,8 +102,7 @@ shipping label.
 
 =head1 API DOCUMENTATION
 
-For more information about Shipment objects, consult the Shippo API
-documentation:
+For more information about Shipments, consult the Shippo API documentation:
 
 =over 2
 
